@@ -5,9 +5,9 @@ use warnings;
 package MooX::Press;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.054';
+our $VERSION   = '0.055';
 
-use Types::Standard 1.008003 -is, -types;
+use Types::Standard 1.010000 -is, -types;
 use Types::TypeTiny qw(ArrayLike HashLike);
 use Exporter::Tiny qw(mkopt);
 use Import::Into;
@@ -606,10 +606,10 @@ sub _make_package {
 	
 	if ($opts{is_role}) {
 		no strict 'refs';
+		no warnings 'once';
 		return if ${"$qname\::BUILT"};
 		use_module("$toolkit\::Role")->import::into($qname);
 		use_module("namespace::autoclean")->import::into($qname);
-		${"$qname\::BUILT"} = 1;
 	}
 	else {
 		use_module($toolkit)->import::into($qname);
@@ -630,6 +630,7 @@ sub _make_package {
 		${"$qname\::PREFIX"}   = $opts{prefix};
 		${"$qname\::FACTORY"}  = $opts{factory_package};
 		${"$qname\::TYPES"}    = $opts{type_library};
+		${"$qname\::BUILT"}    = 1;
 	}
 	
 	my $reg;
@@ -685,12 +686,12 @@ sub _make_package {
 		$builder->install_methods($qname, \%methods) if keys %methods;
 	}
 	
-	if (defined $opts{factory_package}) {
+	if (defined $opts{factory_package_can} and defined $opts{factory_package}) {
 		my %methods = $opts{factory_package_can}->$_handle_list_add_nulls;
 		$builder->install_methods($opts{factory_package}, \%methods) if keys %methods;
 	}
 	
-	if (defined $opts{type_library}) {
+	if (defined $opts{type_library_can} and defined $opts{type_library}) {
 		my %methods = $opts{type_library_can}->$_handle_list_add_nulls;
 		$builder->install_methods($opts{type_library}, \%methods) if keys %methods;
 	}
